@@ -22,7 +22,10 @@
 
 import os
 import ctypes
-import collections
+try:
+    from collections import abc
+except ImportError:
+    import collections as abc
 
 from ._compat import text_type, PY2
 from ._fsnative import path2fsn, is_win, _fsn2legacy, fsnative
@@ -130,7 +133,7 @@ def _norm_key(key):
     return key
 
 
-class Environ(collections.MutableMapping):
+class Environ(abc.MutableMapping):
     """Dict[`fsnative`, `fsnative`]: Like `os.environ` but contains unicode
     keys and values under Windows + Python 2.
 
